@@ -4,12 +4,16 @@
     <Outputs Condition="'$(Configuration)|$(Platform)'=='Release|x64'">$(TargetDir)%(Filename).obj;$(TargetDir)%(Filename)_sse2.obj;$(TargetDir)%(Filename)_sse4.obj;$(TargetDir)%(Filename)_avx.obj;$(TargetDir)%(Filename)_avx2.obj;</Outputs>
 */
 
-use std::{fs, path::Path};
+use glob::glob;
+use std::fs;
 
 fn clean_target(target_name: &str, target_arch: &str) {
-    let target_file = format!("src/ispc/lib{}{}", target_name, target_arch);
-    if Path::new(format!("src/ispc/kernel{}", target_arch).as_str()).exists() {
-        fs::remove_file(target_file).unwrap();
+    let target_files = format!("src/ispc/lib{}{}*", target_name, target_arch);
+    for entry in glob(target_files.as_str()).unwrap() {
+        match entry {
+            Ok(target_file) => println!("{:?}", fs::remove_file(target_file).unwrap()),
+            Err(e) => println!("{:?}", e),
+        }
     }
 }
 
